@@ -251,6 +251,7 @@ fn impl_constructor_single(t: &ApiType) -> TokenStream {
 fn impl_provider_impl(types: &[ApiType]) -> TokenStream {
     let journeys = impl_provider_impl_journeys(types);
     let locations = impl_provider_impl_locations(types);
+    let station_board = impl_provider_impl_station_board(types);
     let refresh = impl_provider_impl_refresh(types);
 
     quote! {
@@ -264,6 +265,8 @@ fn impl_provider_impl(types: &[ApiType]) -> TokenStream {
 
             #locations
 
+            #station_board
+
             #refresh
         }
     }
@@ -307,6 +310,25 @@ fn impl_provider_impl_locations(types: &[ApiType]) -> TokenStream {
     }
 }
 
+fn impl_provider_impl_station_board(types: &[ApiType]) -> TokenStream {
+    let parts = types
+        .iter()
+        .map(|t| impl_provider_impl_single(t, quote! {station_board(place, kind, opts)}));
+    quote! {
+        async fn station_board(
+            &self,
+            place: rcore::Place,
+            kind: rcore::StationBoardKind,
+            opts: rcore::StationBoardOptions,
+        ) -> Result<rcore::StationBoardResponse, rcore::Error<<R as Requester>::Error, Self::Error>> {
+            use rcore::Provider;
+            match self {
+                #(#parts),*
+            }
+        }
+    }
+}
+
 fn impl_provider_impl_refresh(types: &[ApiType]) -> TokenStream {
     let parts = types
         .iter()
